Documentation
¶
Overview ¶
Package rpctype contains types of message passed via net/rpc connections between various parts of the system.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ConnectArgs ¶
type ConnectArgs struct {
Name string
}
type ConnectRes ¶
type HubConnectArgs ¶
type HubConnectArgs struct {
// Client/Key are used for authentication.
Client string
Key string
// Manager name, must start with Client.
Manager string
// Manager has started with an empty corpus and requests whole hub corpus.
Fresh bool
// Set of system call names supported by this manager.
// Used to filter out programs with unsupported calls.
Calls []string
// Current manager corpus.
Corpus [][]byte
}
type HubSyncArgs ¶
type HubSyncArgs struct {
// see HubConnectArgs.
Client string
Key string
Manager string
NeedRepros bool
// Programs added to corpus since last sync or connect.
Add [][]byte
// Hashes of programs removed from corpus since last sync or connect.
Del []string
// Repros found since last sync.
Repros [][]byte
}
type HubSyncRes ¶
type NewInputArgs ¶
type PollRes ¶
type PollRes struct {
Candidates []RPCCandidate
NewInputs []RPCInput
MaxSignal signal.Serial
}
type RPCCandidate ¶
type RPCClient ¶
type RPCClient struct {
// contains filtered or unexported fields
}
func NewRPCClient ¶
type RPCServer ¶
type RPCServer struct {
// contains filtered or unexported fields
}
func NewRPCServer ¶
type SyscallReason ¶
Click to show internal directories.
Click to hide internal directories.