Documentation
¶
Overview ¶
Package vm provides an abstract test machine (VM, physical machine, etc) interface for the rest of the system. For convenience test machines are subsequently collectively called VMs. Package wraps vmimpl package interface with some common functionality and higher-level interface.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Shutdown = vmimpl.Shutdown ErrTimeout = vmimpl.ErrTimeout )
Functions ¶
func MonitorExecution ¶
func MonitorExecution(outc <-chan []byte, errc <-chan error, reporter report.Reporter, canExit bool) ( rep *report.Report)
MonitorExecution monitors execution of a program running inside of a VM. It detects kernel oopses in output, lost connections, hangs, etc. outc/errc is what vm.Instance.Run returns, reporter parses kernel output for oopses. If canExit is false and the program exits, it is treated as an error. Returns a non-symbolized crash report, or nil if no error happens.
Types ¶
type BootErrorer ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package gce allows to use Google Compute Engine (GCE) virtual machines as VMs.
|
Package gce allows to use Google Compute Engine (GCE) virtual machines as VMs. |
|
Package kvm provides VMs based on lkvm (kvmtool) virtualization.
|
Package kvm provides VMs based on lkvm (kvmtool) virtualization. |
|
Package vmimpl provides an abstract test machine (VM, physical machine, etc) interface for the rest of the system.
|
Package vmimpl provides an abstract test machine (VM, physical machine, etc) interface for the rest of the system. |
Click to show internal directories.
Click to hide internal directories.